@@ -100,6 +100,21 @@ def get_main_parser(resources, action=None, target=None):
             get_parser.add_argument('urn', nargs='?')
             return get_parser
 
+    if action == 'serve' or action is None:
+        serve_parser = subparsers.add_parser('serve', help='Serve resources')
+        serve_support_resources = {name: res for name, res in list(resources.items()) if hasattr(res, 'do_serve')}
+        resource_action = serve_parser.add_argument('resource', action=DetectResourceAction,
+                                                  help='resource type, %s' % list(serve_support_resources.keys()))
+        resource_action.resources = resources
+        resource_action.supported_resources = serve_support_resources
+        if action is None:
+            serve_parser.add_argument('args', nargs=argparse.REMAINDER)
+        else:
+            serve_parser.add_argument('-p', '--port', action="store", type=int, default=9527, help='serve port')
+            serve_parser.add_argument('--host', action="store", type=str, default='localhost', help='serve host')
+            serve_parser.add_argument('urn', nargs='?')
+            return serve_parser
+
     if action == 'delete' or action is None:
         delete_parser = subparsers.add_parser('delete', help='Delete resources')
         delete_support_resources = {name: res for name, res in list(resources.items()) if hasattr(res, 'do_delete')}
@@ -128,9 +143,10 @@ def get_main_parser(resources, action=None, target=None):
             describe_parser.add_argument('args', nargs=argparse.REMAINDER)
         else:
             describe_parser.add_argument('urn', nargs='?')
-            describe_parser.add_argument('-o', '--output', choices=('json', 'yaml'), action='store', dest='output',
+            describe_parser.add_argument('-o', '--output', choices=('json', 'yaml', 'table'), action='store', dest='output',
                                      help='output format')
             describe_parser.add_argument('-j', '--jsonpath', action="store", type=str, help='trans by jsonpath')
+            describe_parser.add_argument('--no-headers', action='store_true', help='do not show table headers')
             return describe_parser
 
     if action == 'download' or action is None:
@@ -298,7 +314,7 @@ def _main():
             ipython_main()
     elif main_args.action in (
             'get', 'delete', 'create', 'update', 'edit', 'describe',
-            'download', 'upload', 'upload_partial'):
+            'download', 'upload', 'upload_partial', 'serve'):
         parser = get_resource_parser(resources, main_args.action, resources.get(main_args.resource))
         args = parser.parse_args([main_args.resource] + main_args.args)
         resource = resources.get(main_args.resource)
@@ -357,6 +373,12 @@ def _main():
             logger.debug('before describe %s/%s', resource.name, _resource_id)
             resource.do_describe(context, args, _resource_id)
             logger.debug('after describe %s/%s', resource.name, _resource_id)
+        elif main_args.action == 'serve':
+            _resource_id = args.urn or resource_id
+            ensure_true(_resource_id, 'serve resource without id does not support')
+            logger.debug('before serve %s/%s', resource.name, _resource_id)
+            resource.do_serve(context, args, _resource_id)
+            logger.debug('after serve %s/%s', resource.name, _resource_id)
         elif main_args.action == 'download':
             _resource_id = args.urn or resource_id
             ensure_true(_resource_id, 'download resource without id does not support')
