@@ -6,6 +6,7 @@ from typing import List
 from datahub.emitter.mce_builder import make_tag_urn, make_user_urn
 from datahub.metadata.schema_classes import ContainerPropertiesClass
 
+from metadata.utils.page import get_all
 from metadata.exception import MetadataAssertionError
 from metadata.entity.dataset_group import DatasetGroup
 
@@ -46,9 +47,12 @@ class DatasetGroupMixin:
         )
         return dataset_group
 
-    def delete_dataset_group(self, urn: str):
-        return self._delete_entity(urn)
-
+    def delete_dataset_group(self, urn: str, cascade=False, soft=True):
+        if cascade:
+            for urn in get_all(self.get_datasets_by_group, urn):
+                self.delete_dataset(urn, soft=soft)
+        self._delete_entity(urn, soft=soft)
+            
     def change_dataset_group(self, urn: str, group_urn: str, sync_wait=True):
         dataset = self.get_dataset(urn)
         if dataset and group_urn != dataset.group:
@@ -57,17 +61,23 @@ class DatasetGroupMixin:
             if sync_wait:
                 self._sync_check(f'change {urn} group to {group_urn}', lambda : urn not in self.get_datasets_by_group(group_urn))
     
-    def get_datasets_by_group(self, group_urn: str, *, start=0, count=1000):
+    def get_datasets_by_group(self, group_urn: str, *, start=0, count=1000, return_page_info=False):
         if not self.check_entity_exists(group_urn):
             raise MetadataAssertionError(f'DatasetGroup(urn={group_urn}) does not exists')
         r = self._query_graphql('container.relationships', urn=group_urn, types='IsPartOf', direction='INCOMING', start=start, count=count)
         rr = r['data']['container']['relationships']
-        return [i['entity']['urn'] for i in rr['relationships']]
+        rs = [i['entity']['urn'] for i in rr['relationships']]
+        page_info = {
+            'start': rr.get('start'),
+            'count': rr.get('count'),
+            'total': rr.get('total'),
+        }
+        return (rs, page_info) if return_page_info else rs
 
-    def get_dataset_groups_by_facts(self, *, owner: str=None, tags: List[str]=None, search: str='', start=0, count=1000):
+    def get_dataset_groups_by_facts(self, *, owner: str=None, tags: List[str]=None, search: str='', start=0, count=1000, return_page_info=False):
         facts = []
         if tags:
             facts.append(('tags', [make_tag_urn(tag) for tag in tags], False, 'CONTAIN'))
         if owner:
             facts.append(('owners', [make_user_urn(self.context.user_email if owner == 'me' else owner)], False, 'CONTAIN'))
-        return self._get_entities_by_facts(DatasetGroup.entity_type, facts, search=search, start=start, count=count)
\ No newline at end of file
+        return self._get_entities_by_facts(DatasetGroup.entity_type, facts, search=search, start=start, count=count, return_page_info=return_page_info)
\ No newline at end of file
