@@ -5,10 +5,12 @@ import time
 from abc import ABCMeta, abstractmethod
 import json
 import logging
+import shutil
 
 import jwt
 import requests
 import tiefblue
+from tqdm import tqdm
 
 from metadata.utils.url import build_url
 from metadata.exception import MetadataException
@@ -35,11 +37,11 @@ class StorageClient(object, metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def upload(self, key, path):
+    def upload(self, key, path, show_progress_bar=False):
         pass
 
     @abstractmethod
-    def download(self, key, path):
+    def download(self, key, path, show_progress_bar=False):
         pass
 
     @abstractmethod
@@ -51,6 +53,30 @@ class StorageClient(object, metaclass=ABCMeta):
         pass
 
 
+class _PatchedTiefblueClient(tiefblue.Client):
+
+    def download_from_file(self, object_key, file_path, show_progress_bar=False, progress_callback=None):
+        if (not show_progress_bar) and (not progress_callback):
+            return super().download_from_file(object_key, file_path)
+        session = self._session()
+        with session.get(f"{self._base_url}/api/download/{object_key}", stream=True) as resp:
+            total = int(resp.headers.get('content-length', 0))
+            with open(file_path, 'wb') as file, tqdm(
+                desc=os.path.basename(object_key),
+                total=total,
+                unit='iB',
+                unit_scale=True,
+                unit_divisor=1024,
+            ) as bar:
+                acc = 0
+                for data in resp.iter_content(chunk_size=1024):
+                    size = file.write(data)
+                    acc += size
+                    if progress_callback:
+                        progress_callback(acc /(total + 1))
+                    bar.update(size)
+                
+
 class TiefblueStorageClient(StorageClient):
 
     def __init__(self, username, password, *, bohrium_endpoint=None, tiefblue_endpoint=None, **options):
@@ -63,14 +89,14 @@ class TiefblueStorageClient(StorageClient):
 
         self.bohrium_token = None
         self.bohrium_last_refresh_at = None
+
         self.refresh_bohrium_ephemeral_token()
 
         self.tiefblue_token = None
         self.tiefblue_last_refresh_at = None
         self.client = None
-        self.refresh_tiefblue_ephemeral_token()
 
-        self.client = tiefblue.Client(base_url=self.tiefblue_endpoint, token=self.tiefblue_token)
+        self.refresh_tiefblue_ephemeral_token()
 
     def get_name(self):
         return 'tiefblue'
@@ -135,18 +161,18 @@ class TiefblueStorageClient(StorageClient):
                 raise Exception(f"error code return : {res}")
             self.tiefblue_token = res["data"]["token"]
             self.tiefblue_last_refresh_at = self.parse_token(self.tiefblue_token)['exp']
-            self.client = tiefblue.Client(base_url=self.tiefblue_endpoint, token=self.tiefblue_token)
+            self.client = _PatchedTiefblueClient(base_url=self.tiefblue_endpoint, token=self.tiefblue_token)
         except Exception as e:
             raise MetadataException('failed get token ephemeral from bohrium') from e
   
-    def upload(self, key, path):
+    def upload(self, key, path, show_progress_bar=False):
         self.check_refresh()
-        self.client.upload_from_file(key, path)
+        self.client.upload_from_file(key, path, progress_bar=show_progress_bar)
 
-    def download(self, key, path):
+    def download(self, key, path, show_progress_bar=False, progress_callback=None):
         self.check_refresh()
         os.makedirs(os.path.dirname(path), exist_ok=True)
-        self.client.download_from_file(key, path)
+        self.client.download_from_file(key, path, show_progress_bar=show_progress_bar, progress_callback=progress_callback)
 
     def list(self, prefix, recursive=False):
         self.check_refresh()
@@ -169,4 +195,8 @@ class TiefblueStorageClient(StorageClient):
     
     def delete(self, key):
         self.check_refresh()
-        self.client.delete(key)
\ No newline at end of file
+        self.client.delete(key)
+    
+    def get_meta(self, key):
+        self.check_refresh()
+        return self.client.meta(key)
\ No newline at end of file
